@@ -252,7 +252,7 @@ shishi_aprep_from_file (Shishi * handle, Shishi_asn1 * aprep,
 int
 shishi_aprep_enc_part_set (Shishi * handle,
 			   Shishi_asn1 aprep,
-			   int etype, const char *buf, int buflen)
+			   int etype, const char *buf, size_t buflen)
 {
   int res;
 
@@ -330,7 +330,7 @@ shishi_aprep_enc_part_make (Shishi * handle,
   if (encapreppart == NULL)
     {
       shishi_error_printf (handle, "Could not create EncAPRepPart: %s\n",
-			   shishi_strerror_details (handle));
+			   shishi_error (handle));
       return SHISHI_ASN1_ERROR;
     }
 
@@ -338,7 +338,7 @@ shishi_aprep_enc_part_make (Shishi * handle,
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not copy time: %s\n",
-			   shishi_strerror_details (handle));
+			   shishi_error (handle));
       return res;
     }
 
@@ -347,7 +347,7 @@ shishi_aprep_enc_part_make (Shishi * handle,
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not add encapreppart: %s\n",
-			   shishi_strerror_details (handle));
+			   shishi_error (handle));
       return res;
     }
 
@@ -434,11 +434,12 @@ int
 shishi_aprep_verify (Shishi * handle,
 		     Shishi_asn1 authenticator, Shishi_asn1 encapreppart)
 {
-  char authenticatorctime[GENERALIZEDTIME_TIME_LEN + 1];
-  char encapreppartctime[GENERALIZEDTIME_TIME_LEN + 1];
+  char *authenticatorctime;
+  char *encapreppartctime;
   int authenticatorcusec;
   int encapreppartcusec;
   int res;
+  int different;
 
   /*
      3.2.5. Receipt of KRB_AP_REP message
@@ -452,8 +453,8 @@ shishi_aprep_verify (Shishi * handle,
 
    */
 
-  res = shishi_authenticator_ctime_get (handle, authenticator,
-					authenticatorctime);
+  res = shishi_authenticator_ctime (handle, authenticator,
+				    &authenticatorctime);
   if (res != SHISHI_OK)
     return res;
 
@@ -462,8 +463,7 @@ shishi_aprep_verify (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_encapreppart_ctime_get (handle, encapreppart,
-				       encapreppartctime);
+  res = shishi_encapreppart_ctime (handle, encapreppart, &encapreppartctime);
   if (res != SHISHI_OK)
     return res;
 
@@ -480,9 +480,13 @@ shishi_aprep_verify (Shishi * handle,
 	      encapreppartctime);
     }
 
+  different = authenticatorcusec != encapreppartcusec ||
+    strcmp (authenticatorctime, encapreppartctime) != 0;
 
-  if (authenticatorcusec != encapreppartcusec ||
-      strcmp (authenticatorctime, encapreppartctime) != 0)
+  free (authenticatorctime);
+  free (encapreppartctime);
+
+  if (different)
     return SHISHI_APREP_VERIFY_FAILED;
 
   return SHISHI_OK;
