@@ -827,7 +827,6 @@ cipherinfo des_cbc_crc_info = {
   SHISHI_DES_CBC_CRC,
   "des-cbc-crc",
   8,
-  4,
   8,
   8,
   8,
@@ -842,7 +841,6 @@ cipherinfo des_cbc_md4_info = {
   SHISHI_DES_CBC_MD4,
   "des-cbc-md4",
   8,
-  0,
   8,
   8,
   8,
@@ -857,7 +855,6 @@ cipherinfo des_cbc_md5_info = {
   SHISHI_DES_CBC_MD5,
   "des-cbc-md5",
   8,
-  0,
   8,
   8,
   8,
@@ -872,10 +869,9 @@ cipherinfo des_cbc_none_info = {
   SHISHI_DES_CBC_NONE,
   "des-cbc-none",
   8,
-  0,
   8,
-  3 * 8,
-  3 * 8,
+  8,
+  8,
   SHISHI_RSA_MD5_DES,
   des_random_to_key,
   des_string_to_key,
