@@ -35,10 +35,11 @@ shishi_enckdcreppart (Shishi * handle)
   /* XXX remove these two: */
   res = shishi_asn1_write (handle, node, "key-expiration", NULL, 0);
   if (res != SHISHI_OK)
-    puts ("urk");
+    return NULL;
+
   res = shishi_asn1_write (handle, node, "caddr", NULL, 0);
   if (res != SHISHI_OK)
-    puts ("urk2");
+    return NULL;
 
   return node;
 }
@@ -349,25 +350,20 @@ shishi_enckdcreppart_server_set (Shishi * handle,
   int res;
   int i;
 
-  tmpserver = strdup (server);
-  if (tmpserver == NULL)
-    return SHISHI_MALLOC_ERROR;
+  tmpserver = xstrdup (server);
 
-  serverbuf = malloc (sizeof (*serverbuf));
+  serverbuf = xmalloc (sizeof (*serverbuf));
   for (i = 0;
        (serverbuf[i] = strtok_r (i == 0 ? tmpserver : NULL, "/", &tokptr));
        i++)
     {
-      serverbuf = realloc (serverbuf, (i + 2) * sizeof (*serverbuf));
-      if (serverbuf == NULL)
-	return SHISHI_MALLOC_ERROR;
+      serverbuf = xrealloc (serverbuf, (i + 2) * sizeof (*serverbuf));
     }
   res = shishi_enckdcreppart_sname_set (handle, enckdcreppart,
 					SHISHI_NT_PRINCIPAL, serverbuf);
   if (res != SHISHI_OK)
     {
-      fprintf (stderr, _("Could not set sname: %s\n"),
-	       shishi_strerror_details (handle));
+      fprintf (stderr, _("Could not set sname: %s\n"), shishi_error (handle));
       return res;
     }
   free (serverbuf);
