@@ -31,6 +31,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
+#include <string.h>
 #endif
 
 #ifdef HAVE_SYS_TYPES_H
@@ -88,16 +89,6 @@
 # endif
 #endif
 
-#if HAVE_STRING_H
-# if !STDC_HEADERS && HAVE_MEMORY_H
-#  include <memory.h>
-# endif
-# include <string.h>
-#endif
-#if HAVE_STRINGS_H
-# include <strings.h>
-#endif
-
 #ifdef HAVE_SIGNAL_H
 #include <signal.h>
 #endif
@@ -119,19 +110,23 @@
 #include <resolv.h>
 #endif
 
-#ifdef HAVE_SYSLOG_H 
-#include <syslog.h> 
-#endif 
+#ifdef HAVE_SYSLOG_H
+#include <syslog.h>
+#endif
 
 #include "gettext.h"
 
 #include "base64.h"
 #include "getdate.h"
+#include "getline.h"
+#include "linebuffer.h"
 #include "time_r.h"
 #include "timegm.h"
 #include "vasprintf.h"
 #include "xalloc.h"
 #include "xmemdup.h"
+#include "xgethostname.h"
+#include "xgetdomainname.h"
 #include "xstrndup.h"
 
 #include "shishi.h"
@@ -164,10 +159,6 @@
 		  SHISHI_VERBOSE_CRYPTO_NOICE)
 #define VERBOSE(h) (h->verbose & ~VERBOSES)
 
-#ifndef HOST_NAME_MAX
-#define HOST_NAME_MAX BUFSIZ
-#endif
-
 enum
 {
   UDP,
@@ -204,6 +195,8 @@ struct Shishi
   int renewlife;
   int32_t *clientkdcetypes;
   size_t nclientkdcetypes;
+  int32_t *authorizationtypes;
+  size_t nauthorizationtypes;
   struct Shishi_realminfo *realminfos;
   size_t nrealminfos;
   char *kdc;
@@ -264,6 +257,11 @@ int
 shishi_asn1_integer2_field (Shishi * handle,
 			    Shishi_asn1 node, unsigned long *i,
 			    const char *field);
+int
+_shishi_sendrecv_tls (Shishi * handle,
+		      struct sockaddr *addr,
+		      const char *indata, int inlen,
+		      char **outdata, int *outlen, int timeout);
 
 /* utils.c */
 extern void _shishi_escapeprint (const char *str, int len);
