@@ -182,179 +182,33 @@ shishi_sendrecv_tcp (Shishi * handle,
   return SHISHI_OK;
 }
 
-#ifdef USE_GNUTLS
-
-#include <gnutls/gnutls.h>
-
-/* XXX this is bogus, we should do a STARTTLS approach instead.
-
-   I.e., first send KDC-REQ in clear with PA-STARTTLS preauth data,
-   and if KDC doesn't reject it, start tls on that session.
-   For udp we shouldn't do anything at all.
-
-   Also need to add code to map client certificate X.509 into
-   pre authenticated principal.
-
-   Derive Kerberos EncKDCRepPart key from TLS PRF?  Hm.
-
-   Simpler: Use leading reserved bit in TCP length field to mean
-   STARTTLS.  (Probably better to have it mean that a new octet is
-   present, and that a 0 in that field means STARTTLS, and all other
-   fields are reserved, for future extensions.)
-*/
-
-static int
-shishi_sendrecv_tls (Shishi * handle,
-		     struct sockaddr *addr,
-		     const char *indata, int inlen,
-		     char **outdata, int *outlen, int timeout)
-{
-  char tmpbuf[BUFSIZ];		/* XXX can we do without it?
-				   MSG_PEEK|MSG_TRUNC doesn't work for udp.. */
-  int i;
-  int sockfd;
-  int ret;
-  gnutls_session session;
-  gnutls_certificate_credentials xcred;
-  /* Allow connections to servers that have OpenPGP keys as well.
-   */
-  const int cert_type_priority[3] = { GNUTLS_CRT_X509,
-    GNUTLS_CRT_OPENPGP, 0
-  };
-
-  sockfd = socket (AF_INET, SOCK_STREAM, 0);
-  if (sockfd < 0)
-    {
-      shishi_error_set (handle, strerror (errno));
-      return SHISHI_SOCKET_ERROR;
-    }
-
-  if (connect (sockfd, addr, sizeof (*addr)) != 0)
-    {
-      shishi_error_set (handle, strerror (errno));
-      close (sockfd);
-      return SHISHI_CONNECT_ERROR;
-    }
-
-  gnutls_global_init ();
-
-  /* X509 stuff */
-  gnutls_certificate_allocate_credentials (&xcred);
-
-  /* set's the trusted cas file
-   */
-  //gnutls_certificate_set_x509_trust_file(xcred, CAFILE, GNUTLS_X509_FMT_PEM);
-  /* Initialize TLS session 
-   */
-  gnutls_init (&session, GNUTLS_CLIENT);
-
-  /* Use default priorities */
-  gnutls_set_default_priority (session);
-  gnutls_certificate_type_set_priority (session, cert_type_priority);
-
-  /* put the x509 credentials to the current session
-   */
-  gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
-
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr) sockfd);
-
-  /* Perform the TLS handshake
-   */
-  ret = gnutls_handshake (session);
-
-  if (ret < 0)
-    {
-      fprintf (stderr, "*** Handshake failed\n");
-      gnutls_perror (ret);
-    }
-  else
-    {
-      printf ("- Handshake was completed\n");
-    }
-
-  tmpbuf[3] = inlen & 0xFF;
-  tmpbuf[2] = (inlen >> 8) & 0xFF;
-  tmpbuf[1] = (inlen >> 16) & 0xFF;
-  tmpbuf[0] = (inlen >> 24) & 0xFF;
-
-  gnutls_record_send (session, tmpbuf, 4);
-
-  gnutls_record_send (session, indata, inlen);
-
-  ret = gnutls_record_recv (session, tmpbuf, sizeof (tmpbuf));
-  if (ret == 0)
-    {
-      printf ("- Peer has closed the TLS connection\n");
-    }
-  else if (ret < 0)
-    {
-      fprintf (stderr, "*** Error: %s\n", gnutls_strerror (ret));
-    }
-  else if (ret > 0)
-    {
-      printf ("- Received %d bytes: ", ret);
-      for (i = 0; i < ret; i++)
-	{
-	  fputc (tmpbuf[i], stdout);
-	}
-      fputs ("\n", stdout);
-    }
-  gnutls_bye (session, GNUTLS_SHUT_RDWR);
-
-  shutdown (sockfd, SHUT_RDWR);	/* no more receptions */
-
-  if (close (sockfd) != 0)
-    {
-      shishi_error_set (handle, strerror (errno));
-      return SHISHI_CLOSE_ERROR;
-    }
-
-  gnutls_deinit (session);
-
-  gnutls_certificate_free_credentials (xcred);
-
-  gnutls_global_deinit ();
-
-  *outlen = ret - 4;
-  *outdata = xmalloc (*outlen);
-  memcpy (*outdata, tmpbuf + 4, *outlen);
-
-  return SHISHI_OK;
-}
-
-#else
-
-static int
-shishi_sendrecv_tls (Shishi * handle,
-		     struct sockaddr *addr,
-		     const char *indata, int inlen,
-		     char **outdata, int *outlen, int timeout)
-{
-  return !SHISHI_OK;
-}
-
-#endif
-
 static int
 shishi_kdc_sendrecv_1 (Shishi * handle, struct Shishi_kdcinfo *ki,
 		       const char *indata, size_t inlen,
 		       char **outdata, size_t * outlen)
 {
+  char *protname = ki->protocol == TCP ? "tcp" : "udp";
   int rc;
 
+#ifdef USE_STARTTLS
+  if (ki->protocol == TLS)
+    protname = "tls";
+#endif
+
   if (VERBOSE (handle))
     printf ("Sending to %s (%s) via %s...\n", ki->name,
 	    inet_ntoa (((struct sockaddr_in *) &ki->sockaddress)->sin_addr),
-	    ki->protocol == TCP ? "tcp" : ki->protocol ==
-	    TLS ? "tls" : "udp");
+	    protname);
 
   switch (ki->protocol)
     {
+#ifdef USE_STARTTLS
     case TLS:
-      rc = shishi_sendrecv_tls (handle, &ki->sockaddress,
-				indata, inlen, outdata, outlen,
-				handle->kdctimeout);
+      rc = _shishi_sendrecv_tls (handle, &ki->sockaddress,
+				 indata, inlen, outdata, outlen,
+				 handle->kdctimeout);
       break;
+#endif
 
     case TCP:
       rc = shishi_sendrecv_tcp (handle, &ki->sockaddress,
