@@ -37,21 +37,25 @@
 char *
 shishi_realm_default_guess (void)
 {
-  char buf[HOST_NAME_MAX];
-  int ret;
+  char *realm;
 
-  ret = getdomainname (buf, sizeof (buf));
-  buf[sizeof (buf) - 1] = '\0';
-  if (ret != 0 || strlen (buf) == 0 || strcmp (buf, "(none)") == 0)
-    {
-      ret = gethostname (buf, sizeof (buf));
-      buf[sizeof (buf) - 1] = '\0';
+  realm = xgetdomainname ();
+  if (realm && strlen (realm) > 0 && strcmp (realm, "(none)") != 0)
+    return realm;
 
-      if (ret != 0)
-	strcpy (buf, "could-not-guess-default-realm");
-    }
+  if (realm)
+    free (realm);
 
-  return xstrdup (buf);
+  realm = xgethostname ();
+  if (realm && strlen (realm) > 0 || strcmp (realm, "(none)") != 0)
+    return realm;
+
+  if (realm)
+    free (realm);
+
+  realm = strdup ("could-not-guess-default-realm");
+
+  return realm;
 }
 
 /**
