@@ -3,18 +3,18 @@
  *
  * This file is part of Shishi.
  *
- * Shishi is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * Shishi is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * Shishi is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with Shishi; if not, write to the Free Software
+ * You should have received a copy of the GNU General Public License
+ * along with Shishi; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -106,6 +106,8 @@
 #include <netinet/in6.h>
 #endif
 
+#include <shishi.h>
+
 const char *program_name = PACKAGE;
 
 static int verbose = 0;
@@ -173,6 +175,7 @@ hexprint (const unsigned char *str, int len)
       if ((i + 1) % 16 == 0 && i + 1 < len)
 	printf ("\n\t ;; ");
     }
+  puts("");
 }
 
 static void
@@ -199,4 +202,52 @@ binprint (const unsigned char *str, int len)
       if ((i + 1) % 6 == 0 && i + 1 < len)
 	printf ("\n\t ;; ");
     }
+  puts("");
+}
+
+void test (Shishi * handle);
+
+int
+main (int argc, char *argv[])
+{
+  Shishi *handle;
+
+  do
+    if (strcmp (argv[argc - 1], "-v") == 0 ||
+	strcmp (argv[argc - 1], "--verbose") == 0)
+      verbose = 1;
+    else if (strcmp (argv[argc - 1], "-d") == 0 ||
+	     strcmp (argv[argc - 1], "--debug") == 0)
+      debug = 1;
+    else if (strcmp (argv[argc - 1], "-b") == 0 ||
+	     strcmp (argv[argc - 1], "--break-on-error") == 0)
+      break_on_error = 1;
+    else if (strcmp (argv[argc - 1], "-h") == 0 ||
+	     strcmp (argv[argc - 1], "-?") == 0 ||
+	     strcmp (argv[argc - 1], "--help") == 0)
+      {
+	printf ("Usage: %s [-vdbh?] [--verbose] [--debug] "
+		"[--break-on-error] [--help]\n", argv[0]);
+	return 1;
+      }
+  while (argc-- > 1);
+
+  handle = shishi ();
+  if (handle == NULL)
+    {
+      fail ("Could not initialize shishi\n");
+      return 1;
+    }
+
+  if (debug)
+    shishi_cfg (handle, strdup ("verbose"));
+
+  test (handle);
+
+  shishi_done (handle);
+
+  if (verbose)
+    printf ("Self test `%s' done with %d errors\n", argv[0], error_count);
+
+  return error_count ? 1 : 0;
 }
